Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: media/mojo/services/mojo_video_decoder.h

Issue 1800953002: Add MojoVideoDecoder. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Comments. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/mojo/services/mojo_decoder_factory.cc ('k') | media/mojo/services/mojo_video_decoder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/mojo/services/mojo_video_decoder.h
diff --git a/media/mojo/services/mojo_audio_decoder.h b/media/mojo/services/mojo_video_decoder.h
similarity index 56%
copy from media/mojo/services/mojo_audio_decoder.h
copy to media/mojo/services/mojo_video_decoder.h
index 041bee8981024d2632581858eeaa24b8b28f7a13..cee3a0d86ffce501b269aa2df1399b3f2b6026da 100644
--- a/media/mojo/services/mojo_audio_decoder.h
+++ b/media/mojo/services/mojo_video_decoder.h
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef MEDIA_MOJO_SERVICES_MOJO_AUDIO_DECODER_H_
-#define MEDIA_MOJO_SERVICES_MOJO_AUDIO_DECODER_H_
+#ifndef MEDIA_MOJO_SERVICES_MOJO_VIDEO_DECODER_H_
+#define MEDIA_MOJO_SERVICES_MOJO_VIDEO_DECODER_H_
#include "base/macros.h"
#include "base/memory/ref_counted.h"
-#include "media/base/audio_decoder.h"
+#include "media/base/video_decoder.h"
namespace base {
class SingleThreadTaskRunner;
@@ -15,15 +15,16 @@ class SingleThreadTaskRunner;
namespace media {
-// An AudioDecoder that proxies to a interfaces::AudioDecoder.
-class MojoAudioDecoder : public AudioDecoder {
+// A VideoDecoder that proxies to an interfaces::VideoDecoder.
+class MojoVideoDecoder : public VideoDecoder {
public:
- MojoAudioDecoder();
- ~MojoAudioDecoder() final;
+ MojoVideoDecoder();
+ ~MojoVideoDecoder() final;
- // AudioDecoder implementation.
+ // VideoDecoder implementation.
std::string GetDisplayName() const final;
- void Initialize(const AudioDecoderConfig& config,
+ void Initialize(const VideoDecoderConfig& config,
+ bool low_delay,
CdmContext* cdm_context,
const InitCB& init_cb,
const OutputCB& output_cb) final;
@@ -31,13 +32,15 @@ class MojoAudioDecoder : public AudioDecoder {
const DecodeCB& decode_cb) final;
void Reset(const base::Closure& closure) final;
bool NeedsBitstreamConversion() const final;
+ bool CanReadWithoutStalling() const final;
+ int GetMaxDecodeRequests() const final;
private:
scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
- DISALLOW_COPY_AND_ASSIGN(MojoAudioDecoder);
+ DISALLOW_COPY_AND_ASSIGN(MojoVideoDecoder);
};
} // namespace media
-#endif // MEDIA_MOJO_SERVICES_MOJO_AUDIO_DECODER_H_
+#endif // MEDIA_MOJO_SERVICES_MOJO_VIDEO_DECODER_H_
« no previous file with comments | « media/mojo/services/mojo_decoder_factory.cc ('k') | media/mojo/services/mojo_video_decoder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698